@@ -20,8 +20,8 @@
 #' @param min_recurrence Threshold to define which pixels count towards the GSW
 #' recurrence area `[0, 100]`.
 #' @keywords indicator
-#' @returns A function that returns a tibble with a column for the aggregated
-#'   GSW recurrence indicator.
+#' @returns A function that returns an indicator tibble with recurrence as
+#'   variable and the corresponding area (in ha) as value.
 #' @include register.R
 #' @export
 #' @examples
@@ -104,7 +104,7 @@ calc_gsw_recurrence <- function(engine = "extract", min_recurrence = NULL) {
       tidyr::pivot_longer(cols = dplyr::everything(), names_to = "variable") %>%
       dplyr::mutate(
         variable = "gsw_recurrence",
-        datetime = as.Date("2021-01-01"),
+        datetime = as.POSIXct("2021-01-01T00:00:00Z"),
         unit = "ha"
       ) %>%
       dplyr::select(datetime, variable, unit, value)
